@@ -4,7 +4,7 @@ use std::io::{BufRead, BufReader, Write};
 use std::path::{Path, PathBuf, StripPrefixError};
 use std::time::Duration;
 
-use nix::sys::statfs::{statfs, CGROUP2_SUPER_MAGIC, TMPFS_MAGIC};
+use nix::sys::statfs::{CGROUP2_SUPER_MAGIC, TMPFS_MAGIC, statfs};
 use nix::unistd::Pid;
 use oci_spec::runtime::LinuxResources;
 #[cfg(any(feature = "cgroupsv2_devices", feature = "v1"))]
@@ -280,7 +280,7 @@ pub fn get_cgroup_setup_with_root(root_path: &Path) -> Result<CgroupSetup, GetCg
             // hybrid mode. If a cgroup2 filesystem has been mounted under the "unified"
             // folder we are in hybrid mode, otherwise we are in legacy mode.
             let stat = statfs(root_path)
-                .map_err(|err| std::io::Error::new(std::io::ErrorKind::Other, err))
+                .map_err(std::io::Error::other)
                 .wrap_other(root_path)?;
             if stat.filesystem_type() == CGROUP2_SUPER_MAGIC {
                 return Ok(CgroupSetup::Unified);
@@ -290,7 +290,7 @@ pub fn get_cgroup_setup_with_root(root_path: &Path) -> Result<CgroupSetup, GetCg
                 let unified = &Path::new(root_path).join("unified");
                 if Path::new(unified).exists() {
                     let stat = statfs(unified)
-                        .map_err(|err| std::io::Error::new(std::io::ErrorKind::Other, err))
+                        .map_err(std::io::Error::other)
                         .wrap_other(unified)?;
                     if stat.filesystem_type() == CGROUP2_SUPER_MAGIC {
                         return Ok(CgroupSetup::Hybrid);
@@ -412,6 +412,8 @@ fn create_systemd_cgroup_manager(
     cgroup_path: &Path,
     container_name: &str,
 ) -> Result<systemd::manager::Manager, systemd::manager::SystemdManagerError> {
+    use crate::systemd::manager::PROCESS_IN_CGROUP_TIMEOUT_DURATION;
+
     if !systemd::booted() {
         panic!(
             "systemd cgroup flag passed, but systemd support for managing cgroups is not available"
@@ -429,6 +431,7 @@ fn create_systemd_cgroup_manager(
         cgroup_path.to_owned(),
         container_name.into(),
         use_system,
+        PROCESS_IN_CGROUP_TIMEOUT_DURATION,
     )
 }
 
