@@ -1,13 +1,19 @@
-use anyhow::{bail, Context, Result};
+use std::collections::HashMap;
+use std::fmt::Display;
+use std::fs;
+use std::num::ParseIntError;
+use std::path::{Path, PathBuf};
+
 use serde::Serialize;
-use std::{collections::HashMap, fmt::Display, fs, path::Path};
 
 use super::common;
+use crate::common::{WrapIoResult, WrappedIoError};
 
-pub trait StatsProvider {
+pub(crate) trait StatsProvider {
+    type Error;
     type Stats;
 
-    fn stats(cgroup_path: &Path) -> Result<Self::Stats>;
+    fn stats(cgroup_path: &Path) -> Result<Self::Stats, Self::Error>;
 }
 
 /// Reports the statistics for a cgroup
@@ -32,6 +38,8 @@ pub struct CpuStats {
     pub usage: CpuUsage,
     /// Cpu Throttling statistics for the cgroup
     pub throttling: CpuThrottling,
+    /// Pressure Stall Information
+    pub psi: PSIStats,
 }
 
 /// Reports the cpu usage for a cgroup
@@ -79,6 +87,8 @@ pub struct MemoryStats {
     pub hierarchy: bool,
     /// Various memory statistics
     pub stats: HashMap<String, u64>,
+    /// Pressure Stall Information
+    pub psi: PSIStats,
 }
 
 /// Reports memory stats for one type of memory
@@ -104,7 +114,7 @@ pub struct PidStats {
 }
 
 /// Reports block io stats for a cgroup
-#[derive(Debug, Default, PartialEq, Eq, Serialize)]
+#[derive(Debug, Default, PartialEq, Serialize)]
 pub struct BlkioStats {
     // Number of bytes transferred to/from a device by the cgroup
     pub service_bytes: Vec<BlkioDeviceStat>,
@@ -122,6 +132,8 @@ pub struct BlkioStats {
     pub queued: Vec<BlkioDeviceStat>,
     // Number of requests merged into requests for I/O operations
     pub merged: Vec<BlkioDeviceStat>,
+    /// Pressure Stall Information
+    pub psi: PSIStats,
 }
 
 /// Reports single stat value for a specific device
@@ -162,8 +174,37 @@ pub struct HugeTlbStats {
     pub fail_count: u64,
 }
 
+/// Reports Pressure Stall Information for a cgroup
+#[derive(Debug, Default, PartialEq, Serialize)]
+pub struct PSIStats {
+    /// Percentage of walltime that some (one or more) tasks were delayed due to lack of resources
+    pub some: PSIData,
+    /// Percentage of walltime in which all tasks were delayed by lack of resources
+    pub full: PSIData,
+}
+
+#[derive(Debug, Default, PartialEq, Serialize)]
+pub struct PSIData {
+    /// Running average over the last 10 seconds
+    pub avg10: f64,
+    /// Running average over the last 60 seconds
+    pub avg60: f64,
+    /// Running average over the last 300 seconds
+    pub avg300: f64,
+}
+
+#[derive(thiserror::Error, Debug)]
+pub enum SupportedPageSizesError {
+    #[error("io error: {0}")]
+    Io(#[from] std::io::Error),
+    #[error("failed to parse value {value}: {err}")]
+    Parse { value: String, err: ParseIntError },
+    #[error("failed to determine page size from {dir_name}")]
+    Failed { dir_name: String },
+}
+
 /// Reports which hugepage sizes are supported by the system
-pub fn supported_page_sizes() -> Result<Vec<String>> {
+pub fn supported_page_sizes() -> Result<Vec<String>, SupportedPageSizesError> {
     let mut sizes = Vec::new();
     for hugetlb_entry in fs::read_dir("/sys/kernel/mm/hugepages")? {
         let hugetlb_entry = hugetlb_entry?;
@@ -172,6 +213,8 @@ pub fn supported_page_sizes() -> Result<Vec<String>> {
         }
 
         let dir_name = hugetlb_entry.file_name();
+        // this name should always be valid utf-8,
+        // so can unwrap without any checks
         let dir_name = dir_name.to_str().unwrap();
 
         sizes.push(extract_page_size(dir_name)?);
@@ -180,12 +223,15 @@ pub fn supported_page_sizes() -> Result<Vec<String>> {
     Ok(sizes)
 }
 
-fn extract_page_size(dir_name: &str) -> Result<String> {
+fn extract_page_size(dir_name: &str) -> Result<String, SupportedPageSizesError> {
     if let Some(size) = dir_name
         .strip_prefix("hugepages-")
         .and_then(|name_stripped| name_stripped.strip_suffix("kB"))
     {
-        let size: u64 = parse_value(size)?;
+        let size: u64 = size.parse().map_err(|err| SupportedPageSizesError::Parse {
+            value: size.into(),
+            err,
+        })?;
 
         let size_moniker = if size >= (1 << 20) {
             (size >> 20).to_string() + "GB"
@@ -198,7 +244,9 @@ fn extract_page_size(dir_name: &str) -> Result<String> {
         return Ok(size_moniker);
     }
 
-    bail!("failed to determine page size from {}", dir_name);
+    Err(SupportedPageSizesError::Failed {
+        dir_name: dir_name.into(),
+    })
 }
 
 /// Parses this string slice into an u64
@@ -209,10 +257,8 @@ fn extract_page_size(dir_name: &str) -> Result<String> {
 /// let value = parse_value("32").unwrap();
 /// assert_eq!(value, 32);
 /// ```
-pub fn parse_value(value: &str) -> Result<u64> {
-    value
-        .parse()
-        .with_context(|| format!("failed to parse {}", value))
+pub fn parse_value(value: &str) -> Result<u64, ParseIntError> {
+    value.parse()
 }
 
 /// Parses a single valued file to an u64
@@ -224,58 +270,82 @@ pub fn parse_value(value: &str) -> Result<u64> {
 /// let value = parse_single_value(&Path::new("memory.current")).unwrap();
 /// assert_eq!(value, 32);
 /// ```
-pub fn parse_single_value(file_path: &Path) -> Result<u64> {
+pub fn parse_single_value(file_path: &Path) -> Result<u64, WrappedIoError> {
     let value = common::read_cgroup_file(file_path)?;
     let value = value.trim();
     if value == "max" {
         return Ok(u64::MAX);
     }
 
-    value.parse().with_context(|| {
-        format!(
-            "failed to parse value {} from {}",
-            value,
-            file_path.display()
-        )
-    })
+    value
+        .parse()
+        .map_err(|err| std::io::Error::new(std::io::ErrorKind::InvalidData, err))
+        .wrap_other(file_path)
+}
+
+#[derive(thiserror::Error, Debug)]
+pub enum ParseFlatKeyedDataError {
+    #[error("io error: {0}")]
+    WrappedIo(#[from] WrappedIoError),
+    #[error("flat keyed data at {path} contains entries that do not conform to 'key value'")]
+    DoesNotConform { path: PathBuf },
+    #[error("failed to parse value {value} from {path}")]
+    FailedToParse {
+        value: String,
+        path: PathBuf,
+        err: ParseIntError,
+    },
 }
 
 /// Parses a file that is structured according to the flat keyed format
-pub fn parse_flat_keyed_data(file_path: &Path) -> Result<HashMap<String, u64>> {
+pub(crate) fn parse_flat_keyed_data(
+    file_path: &Path,
+) -> Result<HashMap<String, u64>, ParseFlatKeyedDataError> {
     let mut stats = HashMap::new();
     let keyed_data = common::read_cgroup_file(file_path)?;
     for entry in keyed_data.lines() {
         let entry_fields: Vec<&str> = entry.split_ascii_whitespace().collect();
         if entry_fields.len() != 2 {
-            bail!(
-                "flat keyed data at {} contains entries that do not conform to 'key value'",
-                &file_path.display()
-            );
+            return Err(ParseFlatKeyedDataError::DoesNotConform {
+                path: file_path.to_path_buf(),
+            });
         }
 
         stats.insert(
             entry_fields[0].to_owned(),
-            entry_fields[1].parse().with_context(|| {
-                format!(
-                    "failed to parse value {} from {}",
-                    entry_fields[0],
-                    file_path.display()
-                )
-            })?,
+            entry_fields[1]
+                .parse()
+                .map_err(|err| ParseFlatKeyedDataError::FailedToParse {
+                    value: entry_fields[0].into(),
+                    path: file_path.to_path_buf(),
+                    err,
+                })?,
         );
     }
 
     Ok(stats)
 }
 
-/// Parses a file that is structed according to the nested keyed format
-pub fn parse_nested_keyed_data(file_path: &Path) -> Result<HashMap<String, Vec<String>>> {
+#[derive(thiserror::Error, Debug)]
+pub enum ParseNestedKeyedDataError {
+    #[error("io error: {0}")]
+    WrappedIo(#[from] WrappedIoError),
+    #[error("nested keyed data at {path} contains entries that do not conform to key format")]
+    DoesNotConform { path: PathBuf },
+}
+
+/// Parses a file that is structured according to the nested keyed format
+pub fn parse_nested_keyed_data(
+    file_path: &Path,
+) -> Result<HashMap<String, Vec<String>>, ParseNestedKeyedDataError> {
     let mut stats: HashMap<String, Vec<String>> = HashMap::new();
     let keyed_data = common::read_cgroup_file(file_path)?;
     for entry in keyed_data.lines() {
         let entry_fields: Vec<&str> = entry.split_ascii_whitespace().collect();
         if entry_fields.len() < 2 || !entry_fields[1..].iter().all(|p| p.contains('=')) {
-            bail!("nested key data at {} contains entries that do not conform to the nested key format", file_path.display());
+            return Err(ParseNestedKeyedDataError::DoesNotConform {
+                path: file_path.to_path_buf(),
+            });
         }
 
         stats.insert(
@@ -291,47 +361,119 @@ pub fn parse_nested_keyed_data(file_path: &Path) -> Result<HashMap<String, Vec<S
     Ok(stats)
 }
 
-/// Parses a file that is structed according to the nested keyed format
-/// # Example
-/// ```
-/// use libcgroups::stats::parse_device_number;
-///
-/// let (major, minor) = parse_device_number("8:0").unwrap();
-/// assert_eq!((major, minor), (8, 0));
-/// ```
-pub fn parse_device_number(device: &str) -> Result<(u64, u64)> {
+#[derive(thiserror::Error, Debug)]
+pub enum ParseDeviceNumberError {
+    #[error("failed to parse device number from {device}: expected 2 parts, found {numbers}")]
+    TooManyNumbers { device: String, numbers: usize },
+    #[error("failed to parse device number from {device}: {err}")]
+    MalformedNumber { device: String, err: ParseIntError },
+}
+
+pub(crate) fn parse_device_number(device: &str) -> Result<(u64, u64), ParseDeviceNumberError> {
     let numbers: Vec<&str> = device.split_terminator(':').collect();
     if numbers.len() != 2 {
-        bail!("failed to parse device number {}", device);
+        return Err(ParseDeviceNumberError::TooManyNumbers {
+            device: device.into(),
+            numbers: numbers.len(),
+        });
     }
 
-    Ok((numbers[0].parse()?, numbers[1].parse()?))
+    Ok((
+        numbers[0]
+            .parse()
+            .map_err(|err| ParseDeviceNumberError::MalformedNumber {
+                device: device.into(),
+                err,
+            })?,
+        numbers[1]
+            .parse()
+            .map_err(|err| ParseDeviceNumberError::MalformedNumber {
+                device: device.into(),
+                err,
+            })?,
+    ))
+}
+
+#[derive(thiserror::Error, Debug)]
+pub enum PidStatsError {
+    #[error("io error: {0}")]
+    WrappedIo(#[from] WrappedIoError),
+    #[error("failed to parse current pids: {0}")]
+    ParseCurrent(ParseIntError),
+    #[error("failed to parse pids limit: {0}")]
+    ParseLimit(ParseIntError),
 }
 
 /// Returns cgroup pid statistics
-pub fn pid_stats(cgroup_path: &Path) -> Result<PidStats> {
+pub fn pid_stats(cgroup_path: &Path) -> Result<PidStats, PidStatsError> {
     let mut stats = PidStats::default();
 
     let current = common::read_cgroup_file(cgroup_path.join("pids.current"))?;
     stats.current = current
         .trim()
         .parse()
-        .context("failed to parse current pids")?;
+        .map_err(PidStatsError::ParseCurrent)?;
 
     let limit =
         common::read_cgroup_file(cgroup_path.join("pids.max")).map(|l| l.trim().to_owned())?;
     if limit != "max" {
-        stats.limit = limit.parse().context("failed to parse pids limit")?;
+        stats.limit = limit.parse().map_err(PidStatsError::ParseLimit)?;
     }
 
     Ok(stats)
 }
 
+pub fn psi_stats(psi_file: &Path) -> Result<PSIStats, WrappedIoError> {
+    let mut stats = PSIStats::default();
+
+    let psi = common::read_cgroup_file(psi_file)?;
+    for line in psi.lines() {
+        match &line[0..4] {
+            "some" => stats.some = parse_psi(&line[4..], psi_file)?,
+            "full" => stats.full = parse_psi(&line[4..], psi_file)?,
+            _ => continue,
+        }
+    }
+
+    Ok(stats)
+}
+
+fn parse_psi(stat_line: &str, path: &Path) -> Result<PSIData, WrappedIoError> {
+    use std::io::{Error, ErrorKind};
+
+    let mut psi_data = PSIData::default();
+
+    for kv in stat_line.split_ascii_whitespace() {
+        match kv.split_once('=') {
+            Some(("avg10", v)) => {
+                psi_data.avg10 = v
+                    .parse()
+                    .map_err(|err| Error::new(ErrorKind::InvalidData, err))
+                    .wrap_other(path)?
+            }
+            Some(("avg60", v)) => {
+                psi_data.avg60 = v
+                    .parse()
+                    .map_err(|err| Error::new(ErrorKind::InvalidData, err))
+                    .wrap_other(path)?
+            }
+            Some(("avg300", v)) => {
+                psi_data.avg300 = v
+                    .parse()
+                    .map_err(|err| Error::new(ErrorKind::InvalidData, err))
+                    .wrap_other(path)?
+            }
+            _ => continue,
+        }
+    }
+
+    Ok(psi_data)
+}
+
 #[cfg(test)]
 mod tests {
-    use crate::test::{create_temp_dir, set_fixture};
-
     use super::*;
+    use crate::test::set_fixture;
 
     #[test]
     fn test_supported_page_sizes_gigabyte() {
@@ -353,8 +495,8 @@ mod tests {
 
     #[test]
     fn test_parse_single_value_valid() {
-        let tmp = create_temp_dir("test_parse_single_value_valid").unwrap();
-        let file_path = set_fixture(&tmp, "single_valued_file", "1200\n").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
+        let file_path = set_fixture(tmp.path(), "single_valued_file", "1200\n").unwrap();
 
         let value = parse_single_value(&file_path).unwrap();
         assert_eq!(value, 1200);
@@ -362,8 +504,8 @@ mod tests {
 
     #[test]
     fn test_parse_single_value_invalid_number() {
-        let tmp = create_temp_dir("test_parse_single_value_invalid_number").unwrap();
-        let file_path = set_fixture(&tmp, "single_invalid_file", "noop\n").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
+        let file_path = set_fixture(tmp.path(), "single_invalid_file", "noop\n").unwrap();
 
         let value = parse_single_value(&file_path);
         assert!(value.is_err());
@@ -371,8 +513,8 @@ mod tests {
 
     #[test]
     fn test_parse_single_value_multiple_entries() {
-        let tmp = create_temp_dir("test_parse_single_value_multiple_entries").unwrap();
-        let file_path = set_fixture(&tmp, "multi_valued_file", "1200\n1400\n1600").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
+        let file_path = set_fixture(tmp.path(), "multi_valued_file", "1200\n1400\n1600").unwrap();
 
         let value = parse_single_value(&file_path);
         assert!(value.is_err());
@@ -380,9 +522,9 @@ mod tests {
 
     #[test]
     fn test_parse_flat_keyed_data() {
-        let tmp = create_temp_dir("test_parse_flat_keyed_data").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
         let file_content = ["key1 1", "key2 2", "key3 3"].join("\n");
-        let file_path = set_fixture(&tmp, "flat_keyed_data", &file_content).unwrap();
+        let file_path = set_fixture(tmp.path(), "flat_keyed_data", &file_content).unwrap();
 
         let actual = parse_flat_keyed_data(&file_path).unwrap();
         let mut expected = HashMap::with_capacity(3);
@@ -395,9 +537,9 @@ mod tests {
 
     #[test]
     fn test_parse_flat_keyed_data_with_characters() {
-        let tmp = create_temp_dir("test_parse_flat_keyed_data_with_characters").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
         let file_content = ["key1 1", "key2 a", "key3 b"].join("\n");
-        let file_path = set_fixture(&tmp, "flat_keyed_data", &file_content).unwrap();
+        let file_path = set_fixture(tmp.path(), "flat_keyed_data", &file_content).unwrap();
 
         let result = parse_flat_keyed_data(&file_path);
         assert!(result.is_err());
@@ -405,9 +547,9 @@ mod tests {
 
     #[test]
     fn test_parse_space_separated_as_flat_keyed_data() {
-        let tmp = create_temp_dir("test_parse_space_separated_as_flat_keyed_data").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
         let file_content = ["key1", "key2", "key3", "key4"].join(" ");
-        let file_path = set_fixture(&tmp, "space_separated", &file_content).unwrap();
+        let file_path = set_fixture(tmp.path(), "space_separated", &file_content).unwrap();
 
         let result = parse_flat_keyed_data(&file_path);
         assert!(result.is_err());
@@ -415,9 +557,9 @@ mod tests {
 
     #[test]
     fn test_parse_newline_separated_as_flat_keyed_data() {
-        let tmp = create_temp_dir("test_parse_newline_separated_as_flat_keyed_data").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
         let file_content = ["key1", "key2", "key3", "key4"].join("\n");
-        let file_path = set_fixture(&tmp, "newline_separated", &file_content).unwrap();
+        let file_path = set_fixture(tmp.path(), "newline_separated", &file_content).unwrap();
 
         let result = parse_flat_keyed_data(&file_path);
         assert!(result.is_err());
@@ -425,14 +567,14 @@ mod tests {
 
     #[test]
     fn test_parse_nested_keyed_data_as_flat_keyed_data() {
-        let tmp = create_temp_dir("test_parse_nested_keyed_data_as_flat_keyed_data").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
         let file_content = [
             "key1 subkey1=value1 subkey2=value2 subkey3=value3",
             "key2 subkey1=value1 subkey2=value2 subkey3=value3",
             "key3 subkey1=value1 subkey2=value2 subkey3=value3",
         ]
         .join("\n");
-        let file_path = set_fixture(&tmp, "nested_keyed_data", &file_content).unwrap();
+        let file_path = set_fixture(tmp.path(), "nested_keyed_data", &file_content).unwrap();
 
         let result = parse_flat_keyed_data(&file_path);
         assert!(result.is_err());
@@ -440,14 +582,14 @@ mod tests {
 
     #[test]
     fn test_parse_nested_keyed_data() {
-        let tmp = create_temp_dir("test_parse_nested_keyed_data").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
         let file_content = [
             "key1 subkey1=value1 subkey2=value2 subkey3=value3",
             "key2 subkey1=value1 subkey2=value2 subkey3=value3",
             "key3 subkey1=value1 subkey2=value2 subkey3=value3",
         ]
         .join("\n");
-        let file_path = set_fixture(&tmp, "nested_keyed_data", &file_content).unwrap();
+        let file_path = set_fixture(tmp.path(), "nested_keyed_data", &file_content).unwrap();
 
         let actual = parse_nested_keyed_data(&file_path).unwrap();
         let mut expected = HashMap::with_capacity(3);
@@ -481,9 +623,9 @@ mod tests {
 
     #[test]
     fn test_parse_space_separated_as_nested_keyed_data() {
-        let tmp = create_temp_dir("test_parse_space_separated_as_nested_keyed_data").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
         let file_content = ["key1", "key2", "key3", "key4"].join(" ");
-        let file_path = set_fixture(&tmp, "space_separated", &file_content).unwrap();
+        let file_path = set_fixture(tmp.path(), "space_separated", &file_content).unwrap();
 
         let result = parse_nested_keyed_data(&file_path);
         assert!(result.is_err());
@@ -491,9 +633,9 @@ mod tests {
 
     #[test]
     fn test_parse_newline_separated_as_nested_keyed_data() {
-        let tmp = create_temp_dir("test_parse_newline_separated_as_nested_keyed_data").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
         let file_content = ["key1", "key2", "key3", "key4"].join("\n");
-        let file_path = set_fixture(&tmp, "newline_separated", &file_content).unwrap();
+        let file_path = set_fixture(tmp.path(), "newline_separated", &file_content).unwrap();
 
         let result = parse_nested_keyed_data(&file_path);
         assert!(result.is_err());
@@ -501,9 +643,9 @@ mod tests {
 
     #[test]
     fn test_parse_flat_keyed_as_nested_keyed_data() {
-        let tmp = create_temp_dir("test_parse_flat_keyed_as_nested_keyed_data").unwrap();
+        let tmp = tempfile::tempdir().unwrap();
         let file_content = ["key1 1", "key2 2", "key3 3"].join("\n");
-        let file_path = set_fixture(&tmp, "newline_separated", &file_content).unwrap();
+        let file_path = set_fixture(tmp.path(), "newline_separated", &file_content).unwrap();
 
         let result = parse_nested_keyed_data(&file_path);
         assert!(result.is_err());
@@ -520,4 +662,52 @@ mod tests {
         let result = parse_device_number("a:b");
         assert!(result.is_err());
     }
+
+    #[test]
+    fn test_parse_psi_full_stats() {
+        let tmp = tempfile::tempdir().unwrap();
+        let file_content = [
+            "some avg10=80.00 avg60=50.00 avg300=90.00 total=0",
+            "full avg10=10.00 avg60=30.00 avg300=50.00 total=0",
+        ]
+        .join("\n");
+        let psi_file = set_fixture(tmp.path(), "psi.pressure", &file_content).unwrap();
+
+        let result = psi_stats(&psi_file).unwrap();
+        assert_eq!(
+            result,
+            PSIStats {
+                some: PSIData {
+                    avg10: 80.0,
+                    avg60: 50.0,
+                    avg300: 90.0
+                },
+                full: PSIData {
+                    avg10: 10.0,
+                    avg60: 30.0,
+                    avg300: 50.0
+                },
+            }
+        )
+    }
+
+    #[test]
+    fn test_parse_psi_only_some() {
+        let tmp = tempfile::tempdir().unwrap();
+        let file_content = ["some avg10=80.00 avg60=50.00 avg300=90.00 total=0"].join("\n");
+        let psi_file = set_fixture(tmp.path(), "psi.pressure", &file_content).unwrap();
+
+        let result = psi_stats(&psi_file).unwrap();
+        assert_eq!(
+            result,
+            PSIStats {
+                some: PSIData {
+                    avg10: 80.0,
+                    avg60: 50.0,
+                    avg300: 90.0
+                },
+                full: PSIData::default(),
+            }
+        )
+    }
 }
