@@ -308,7 +308,7 @@ impl DbusConnection {
 
         // it is possible that while receiving messages, we get some extra/previous message
         // for method calls, we need to have an error or method return type message, so
-        // we keep looping until we get either of these. see https://github.com/containers/youki/issues/2826
+        // we keep looping until we get either of these. see https://github.com/youki-dev/youki/issues/2826
         // for more detailed analysis.
         loop {
             let reply = self.receive_complete_response()?;
@@ -356,11 +356,11 @@ impl DbusConnection {
     }
 
     /// Create a proxy for given destination and path
-    pub fn proxy(&self, destination: &str, path: &str) -> Proxy {
+    pub fn proxy(&self, destination: &str, path: &str) -> Proxy<'_> {
         Proxy::new(self, destination, path)
     }
 
-    fn create_proxy(&self) -> Proxy {
+    fn create_proxy(&self) -> Proxy<'_> {
         self.proxy("org.freedesktop.systemd1", "/org/freedesktop/systemd1")
     }
 }
@@ -500,7 +500,7 @@ mod tests {
     use nix::unistd::getuid;
 
     use super::super::utils::Result;
-    use super::{uid_to_hex_str, DbusConnection, SystemdClientError};
+    use super::{DbusConnection, SystemdClientError, uid_to_hex_str};
 
     #[test]
     fn test_uid_to_hex_str() {
