@@ -4,7 +4,7 @@ use oci_spec::runtime::LinuxCpu;
 
 use super::controller::Controller;
 use crate::common::{self, ControllerOpt, WrappedIoError};
-use crate::stats::{parse_flat_keyed_data, CpuThrottling, ParseFlatKeyedDataError, StatsProvider};
+use crate::stats::{CpuThrottling, ParseFlatKeyedDataError, StatsProvider, parse_flat_keyed_data};
 
 const CGROUP_CPU_SHARES: &str = "cpu.shares";
 const CGROUP_CPU_QUOTA: &str = "cpu.cfs_quota_us";
